@@ -24,11 +24,11 @@ def get_today(tz=LOCAL_TIMEZONE):
     return today
 
 
-# 获取当周周日晚
+# 获取当周周日晚23点23分23秒
 def get_current_week_range_datetime():
     today = get_today()
     start_date = today - timedelta(days=today.weekday())
     end_date = start_date + timedelta(days=7)
     end_date = end_date - timedelta(seconds=1)
-    print(start_date,end_date, '1')
-    return start_date,end_date
+    # print(start_date,end_date, '1')
+    return start_date, end_date
