@@ -46,7 +46,6 @@ class Line(models.Model):
         db_table = 'bee_django_mission_line'
         app_label = 'bee_django_mission'
         ordering = ['id']
-        verbose_name = '任务线'
         permissions = (
             ('can_manage_mission', '可以进入mission管理页'),
         )
@@ -90,7 +89,6 @@ class Stage(models.Model):
         db_table = 'bee_django_mission_stage'
         app_label = 'bee_django_mission'
         ordering = ['level']
-        verbose_name = '阶段任务'
 
     def get_absolute_url(self):
         return reverse('bee_django_mission:stage_unlimited_list')
@@ -177,7 +175,6 @@ class MissionType(models.Model):
         db_table = 'bee_django_mission_type'
         app_label = 'bee_django_mission'
         ordering = ['id']
-        verbose_name = u'任务类型'
 
     def __str__(self):
         return self.name
