@@ -42,11 +42,16 @@ urlpatterns = [
     # ====user mission =====
     # 获取学生的周任务
     url(r'^user/mission/list/week/(?P<user_id>[0-9]+)/$', views.UserMissionListWeek.as_view(), name='user_line_week'),
+    url(r'^custom_user/mission/list/week/(?P<user_id>[0-9]+)/$', views.CustomUserMissionListWeek.as_view(), name='custom_user_line_week'),
+
     # 获取学生的长线任务
     url(r'^user/mission/list/unlimited/(?P<user_id>[0-9]+)/$', views.UserMissionListUnlimited.as_view(),
         name='user_line_unlimited'),
+    url(r'^custom_user/mission/list/unlimited/(?P<user_id>[0-9]+)/$', views.CustomUserMissionListUnlimited.as_view(),
+        name='custom_user_line_unlimited'),
     url(r'^user/mission/update/(?P<pk>[0-9]+)/$', views.UserStageUpdate.as_view(), name='user_stage_update'),
 
     # ==== user stage finish count ======
     url(r'^user/stage/finish/rank/list/(?P<line_id>[0-9]+)/$', views.UserStageFinishRankList.as_view(), name='user_stage_finish_rank_list'),
+    url(r'^custom_user/stage/finish/rank/list/(?P<line_id>[0-9]+)/$', views.CustomUserStageFinishRankList.as_view(), name='custom_user_stage_finish_rank_list'),
 ]
